# TrueFoundry

TrueFoundry library to help you interact with the platform programmatically by

- Interacting with the deployments side of TrueFoundry, enabling you to manage workspaces, deployments, applications, and view logs.
- Providing experiment tracking capabilities, allowing you to track ML experiments and interact with ML repositories within TrueFoundry.

You can access the health of your service, monitoring links, deployed endpoints and track metadata and artifacts by logging on to TrueFoundry's dashboard.

## Installation

To install the `TrueFoundry CLI`, you can use pip:

```bash
pip install truefoundry
```

To install the `TrueFoundry CLI` with Workflow deployment features, you can use pip:

```bash
pip install truefoundry[workflow]
```

## Examples

https://github.com/truefoundry/getting-started-examples

## Documentation

https://docs.truefoundry.com/
